<template>
  <div class="app-container">
    <el-row :gutter="20">
      <el-col :span="4" :xs="24">
        <div class="head-container">
          <el-input
            v-model="deviceName"
            placeholder="请输入设备型号"
            clearable
            prefix-icon="Search"
            style="margin-bottom: 20px"
          />
        </div>
        <div class="head-container">
          <el-tree
            :data="DeviceVersion"
            :props="{ label: 'label', children: 'children' }"
            :expand-on-click-node="false"
            :filter-node-method="filterNode"
            ref="deptTreeRef"
            node-key="id"
            highlight-current
            default-expand-all
            @node-click="handleNodeClick"
          />
        </div>
      </el-col>
      <el-col :span="20" :xs="24">
        <el-form
          :model="queryParams"
          ref="queryRef"
          :inline="true"
          v-show="showSearch"
        >
          <el-form-item label="物料名称" prop="partsName">
            <el-input
              v-model="queryParams.partsName"
              placeholder="请输入物料名称"
              clearable
              style="width: 200px"
              @keyup.enter="handleQuery"
            />
          </el-form-item>

          <el-form-item>
            <el-button type="primary" icon="Search" @click="handleQuery"
              >搜索</el-button
            >
            <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-form>
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button
              type="primary"
              plain
              icon="Plus"
              @click="handleAdd"
              v-hasPermi="['system:notice:add']"
              >新增</el-button
            >
          </el-col>

          <el-col :span="1.5">
            <el-button
              type="danger"
              plain
              icon="Delete"
              :disabled="multiple"
              @click="handleDelete"
              v-hasPermi="['system:notice:remove']"
              >删除</el-button
            >
          </el-col>
          <right-toolbar
            v-model:showSearch="showSearch"
            @queryTable="getList"
          ></right-toolbar>
        </el-row>

        <el-table
          v-loading="loading"
          :data="noticeList"
          @selection-change="handleSelectionChange"
        >
          <el-table-column type="selection" width="55" align="center" />
          <el-table-column
            label="序号"
            align="center"
            type="index"
            width="80"
          />

          <el-table-column label="场景名称" align="center" prop="sceneName">
          </el-table-column>
          <el-table-column label="价格区间" :show-overflow-tooltip="true">
            <template #default="scope">
              {{ scope.row.minPrice }} ~ {{ scope.row.maxPrice }}
            </template>
          </el-table-column>


          <el-table-column
            label="创建时间"
            align="center"
            prop="createTime"

          >
            <!-- <template #default="scope">
            <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d}') }}</span>
         </template> -->
          </el-table-column>
          <el-table-column
            label="操作"
            align="center"
            class-name="small-padding fixed-width"
          >
            <template #default="scope">
              <el-button
                link
                type="primary"
                icon="Edit"
                @click="handleUpdate(scope.row)"
                v-hasPermi="['system:notice:edit']"
                >修改</el-button
              >
              <el-button
                link
                type="danger"
                icon="Delete"
                @click="handleDelete(scope.row)"
                v-hasPermi="['system:notice:remove']"
                >删除</el-button
              >
            </template>
          </el-table-column>
        </el-table>

        <pagination
          v-show="total > 0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
        />
      </el-col>
    </el-row>

    <!-- 添加或修改公告对话框 -->
    <el-dialog :title="title" v-model="open" width="780px" append-to-body>
      <el-form ref="VersionRef" :model="form" :rules="rules" label-width="80px">
        <el-row>
          <el-col :span="24">
            <el-form-item label="场景名称" prop="sceneName">
              <el-input v-model="form.sceneName" placeholder="请输入" />
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="设备类型" prop="deviceVersion">
              <el-select
                v-model="form.deviceVersion"
                placeholder="设备类型"
                @change="changeVerson"
                clearable
              >
                <el-option
                  v-for="item in device_version"
                  :key="item.dictValue"
                  :label="item.dictLabel"
                  :value="item.dictValue"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="配件选择" prop="deviceVersion">
              <el-transfer v-model="device_value"
              :titles="['未选配件', '已选配件']"

              :data="device_list" />
            </el-form-item>
          </el-col>


        </el-row>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="Notice">
import {
  devicePartslist,
  devicePartsPut,
  devicePartsdel,
  deviceRepairDEL,
  deviceRepairParts,
  deviceRepairPUT,
  deviceRepairPOST,
  sceneList
} from "@/api/aftersales/deviceParts";
import { getDicts } from '@/api/system/dict/data'
const { proxy } = getCurrentInstance();


const noticeList = ref([]);
const open = ref(false);
const loading = ref(false);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const DeviceVersion = ref([]);
const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    noticeTitle: undefined,
    createBy: undefined,
    status: undefined,
  },
  rules: {
    sceneName: [{ required: true, message: "不能为空", trigger: "blur" }],

    deviceVersion: [{ required: true, message: "不能为空", trigger: "blur" }],
    partsUnit: [{ required: true, message: "不能为空", trigger: "blur" }],

  },
});

const { queryParams, form, rules } = toRefs(data);

const device_value=ref([])
const device_list=ref([])
const deviceName = ref("");
const device_version =ref([])
function getVersion(){
  getDicts('device_version').then(res=>{
    device_version.value =res.data
    DeviceVersion.value = [
    {
      id: 0,
      label: "所有类型",
      parentId: -1,
      children: res.data.map((item) => {
        return {
          id: item.dictValue,
          label: item.dictLabel,
          parentId: 0,
          ...item,
        };
      }),
    },
  ];
  })
}
getVersion()
/** 根据名称筛选部门树 */
watch(deviceName, (val) => {
  proxy.$refs["deptTreeRef"].filter(val);
});

/** 通过条件过滤节点  */
const filterNode = (value, data) => {
  if (!value) return true;
  return data.label.indexOf(value) !== -1;
};
function handleNodeClick(e) {
  console.log(e);
  queryParams.value.deviceVersion = e.dictValue;
  getList();
}
/** 查询公告列表 */
function getList() {
  loading.value = true;
  sceneList(queryParams.value).then((response) => {
    noticeList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}
function changeVerson(e){
  device_value.value=[]
  getDeviceList(e)
}
/** 查询所属列表 */
function getDeviceList(deviceVersion) {

  devicePartslist({pageNum:1,pageSize:1000,deviceVersion}).then((response) => {
    device_list.value = response.rows.map(item=>{
      return {
        label:item.partsName,
        key:item.partsId,
        ...item
      }
    });
    console.log(device_list.value)
    open.value = true;
  });
}
/** 取消按钮 */
function cancel() {
  open.value = false;
  reset();
}
/** 表单重置 */
function reset() {
  form.value = {
    noticeId: undefined,
    noticeTitle: undefined,
    noticeType: undefined,
    noticeContent: undefined,
    status: "0",
  };
  proxy.resetForm("VersionRef");
}
/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}
/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}
const idName = ref();
/** 多选框选中数据 */
function handleSelectionChange(selection) {
  ids.value = selection.map((item) => item.sceneId);
  idName.value = selection.map((item) => item.sceneName);

  single.value = selection.length != 1;
  multiple.value = !selection.length;
}
/** 新增按钮操作 */
function handleAdd() {
  reset();
  if (queryParams.value.deviceVersion) {
    getDeviceList(queryParams.value.deviceVersion)
    form.value.deviceVersion = queryParams.value.deviceVersion
    title.value = "添加维修场景";
  } else {
    proxy.$modal.msgWarning("请先选择设备型号");
  }
}
/**修改按钮操作 */
function handleUpdate(row) {
  reset();
  form.value = Object.assign({}, row);
  device_value.value=[]
  getDeviceList(row.deviceVersion)
  deviceRepairParts(row.sceneId).then(res=>{
    console.log(res)
    device_value.value=res.data
  })

  title.value = "修改维修场景";
}
/** 提交按钮 */
function submitForm() {
  console.log(device_value.value)
  console.log(form.value)
  form.value.partsIds = device_value.value

  proxy.$refs["VersionRef"].validate((valid) => {
    if (valid) {
      if (form.value.sceneId != undefined) {
        deviceRepairPUT(form.value).then((response) => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        deviceRepairPOST(form.value).then((response) => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}
/** 删除按钮操作 */
function handleDelete(row) {
  const partsId = row.sceneId || ids.value;
  const partsName = row.sceneName || idName.value;
  proxy.$modal
    .confirm('是否确认删除维修场景"' + partsName + '"的数据项？')
    .then(function () {
      return deviceRepairDEL(partsId);
    })
    .then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
    })
    .catch(() => {});
}

getList();
</script>
